@@ -17,12 +17,15 @@
 #include <mach/mach.h>
 #include <mach/mach_vm.h>
 #include <mach/shared_region.h>
+#include <mach/mach_time.h>
 
 #include "ps-internal.h"
 #include "arch/macos/process_info.h"
 
 #include <stdbool.h>
 
+struct mach_timebase_info PS_MACH_TIMEBASE_INFO;
+
 #define PS__TV2DOUBLE(t) ((t).tv_sec + (t).tv_usec / 1000000.0)
 
 #define PS__CHECK_KINFO(kp, handle)				      \
@@ -400,6 +403,8 @@ SEXP psll_cpu_times(SEXP p) {
   ps_handle_t *handle = R_ExternalPtrAddr(p);
   struct proc_taskinfo pti;
   SEXP result, names;
+  uint64_t total_user;
+  uint64_t total_system;
 
   if (!handle) error("Process pointer cleaned up already");
 
@@ -410,9 +415,14 @@ SEXP psll_cpu_times(SEXP p) {
 
   PS__CHECK_HANDLE(handle);
 
+  total_user = pti.pti_total_user * PS_MACH_TIMEBASE_INFO.numer;
+  total_user /= PS_MACH_TIMEBASE_INFO.denom;
+  total_system = pti.pti_total_system * PS_MACH_TIMEBASE_INFO.numer;
+  total_system /= PS_MACH_TIMEBASE_INFO.denom;
+
   PROTECT(result = allocVector(REALSXP, 4));
-  REAL(result)[0] = (double) pti.pti_total_user / 1000000000.0;
-  REAL(result)[1] = (double) pti.pti_total_system / 1000000000.0;
+  REAL(result)[0] = (double) total_user / 1000000000.0;
+  REAL(result)[1] = (double) total_system / 1000000000.0;
   REAL(result)[2] = REAL(result)[3] = NA_REAL;
   PROTECT(names = ps__build_string("user", "system", "children_user",
 				   "children_system", NULL));
@@ -449,7 +459,7 @@ SEXP psll_memory_info(SEXP p) {
   return result;
 }
 
-SEXP ps__boot_time() {
+SEXP ps__boot_time(void) {
 #define MIB_SIZE 2
   int mib[MIB_SIZE];
   size_t size;
@@ -469,7 +479,7 @@ SEXP ps__boot_time() {
   return ScalarReal(unixtime);
 }
 
-SEXP ps__cpu_count_logical() {
+SEXP ps__cpu_count_logical(void) {
   int num = 0;
   size_t size = sizeof(int);
 
@@ -479,7 +489,7 @@ SEXP ps__cpu_count_logical() {
     return ScalarInteger(num);
 }
 
-SEXP ps__cpu_count_physical() {
+SEXP ps__cpu_count_physical(void) {
   int num = 0;
   size_t size = sizeof(int);
 
@@ -944,7 +954,7 @@ SEXP psll_memory_uss(SEXP p) {
   return Rf_ScalarInteger(private_pages * pagesize);
 }
 
-SEXP ps__users() {
+SEXP ps__users(void) {
   struct utmpx *utx;
   SEXP result;
   PROTECT_INDEX pidx;
@@ -1091,7 +1101,7 @@ int ps__sys_vminfo(vm_statistics_data_t *vmstat) {
   return 0;
 }
 
-SEXP ps__system_memory() {
+SEXP ps__system_memory(void) {
   int mib[2];
   uint64_t total;
   size_t len = sizeof(total);
@@ -1125,7 +1135,7 @@ SEXP ps__system_memory() {
   );
 }
 
-SEXP ps__system_swap() {
+SEXP ps__system_swap(void) {
   int mib[2];
   size_t size;
   struct xsw_usage totals;
@@ -1178,7 +1188,7 @@ SEXP ps__loadavg(SEXP counter_name) {
   return ret;
 }
 
-SEXP ps__system_cpu_times() {
+SEXP ps__system_cpu_times(void) {
   mach_msg_type_number_t count = HOST_CPU_LOAD_INFO_COUNT;
   kern_return_t error;
   host_cpu_load_info_data_t r_load;
