@@ -7,6 +7,13 @@
 
 #include "ps-internal.h"
 #include "common.h"
+#include "config.h"
+
+#ifdef PS__MACOS
+#include <mach/mach_time.h>
+extern struct mach_timebase_info PS_MACH_TIMEBASE_INFO;
+#endif
+
 
 static const R_CallMethodDef callMethods[]  = {
   /* System api */
@@ -45,6 +52,7 @@ static const R_CallMethodDef callMethods[]  = {
   { "psll_num_threads",  (DL_FUNC) psll_num_threads , 1 },
   { "psll_cpu_times",    (DL_FUNC) psll_cpu_times,    1 },
   { "psll_memory_info",  (DL_FUNC) psll_memory_info , 1 },
+  { "psll_memory_uss",   (DL_FUNC) psll_memory_uss,   1 },
   { "psll_send_signal",  (DL_FUNC) psll_send_signal , 2 },
   { "psll_suspend",      (DL_FUNC) psll_suspend,      1 },
   { "psll_resume",       (DL_FUNC) psll_resume,       1 },
@@ -57,12 +65,15 @@ static const R_CallMethodDef callMethods[]  = {
   { "psll_get_nice",     (DL_FUNC) psll_get_nice,     1 },
   { "psll_set_nice",     (DL_FUNC) psll_set_nice,     2 },
   { "psll_dlls",         (DL_FUNC) psll_dlls,         1 },
+  { "psll_get_cpu_aff",  (DL_FUNC) psll_get_cpu_aff,  1 },
+  { "psll_set_cpu_aff",  (DL_FUNC) psll_set_cpu_aff,  2 },
 
   /* Utils */
   { "ps__init",          (DL_FUNC) ps__init,          2 },
   { "ps__kill_if_env",   (DL_FUNC) ps__kill_if_env,   4 },
   { "ps__find_if_env",   (DL_FUNC) ps__find_if_env,   3 },
   { "ps__inet_ntop",     (DL_FUNC) ps__inet_ntop,     2 },
+  { "ps__memory_maps",   (DL_FUNC) ps__memory_maps,   1 },
 
   { "psp__pid_exists",   (DL_FUNC) psp__pid_exists,   1 },
   { "psp__stat_st_rdev", (DL_FUNC) psp__stat_st_rdev, 1 },
@@ -92,6 +103,10 @@ void R_init_ps(DllInfo *dll) {
   R_PreserveObject(ps__last_error);
   UNPROTECT(1);
 
+#ifdef PS__MACOS
+  mach_timebase_info(&PS_MACH_TIMEBASE_INFO);
+#endif
+
   R_registerRoutines(dll, NULL, callMethods, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
   R_forceSymbols(dll, TRUE);
